@@ -119,6 +119,21 @@ open_request_logger (GPdfURIInput *in, const char *uri, gpointer user_data)
 }
 #endif
 
+static void
+set_window_icon_default (void)
+{
+	GdkPixbuf *pixbuf;
+
+	pixbuf = gdk_pixbuf_new_from_file (GNOMEICONDIR "/gnome-pdf.png", NULL);
+
+	if (pixbuf == NULL)
+		return;
+
+	gtk_window_set_default_icon (pixbuf);
+
+	g_object_unref (pixbuf);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -141,6 +156,8 @@ main (int argc, char **argv)
 	if (bonobo_ui_init ("GNOME PDF Viewer", VERSION, &argc, argv) == FALSE)
 		g_error (_("Could not initialize Bonobo!\n"));
 
+	set_window_icon_default ();
+
 	client = gnome_master_client ();
 	
 	g_value_init (&value, G_TYPE_POINTER);
@@ -372,55 +389,40 @@ gw_close_all (void)
 }
 
 static void
-file_dialog_ok (GtkWidget *widget, gboolean *dialog_result)
+file_dialog_response (GtkWidget *chooser, gint response, gboolean *dialog_result)
 {
-	GtkFileSelection *fsel;
-	const gchar *file_name;
+	gchar *file_name;
 
-	fsel = GTK_FILE_SELECTION (
-		gtk_widget_get_ancestor (widget, GTK_TYPE_FILE_SELECTION));
-	file_name = gtk_file_selection_get_filename (fsel);
+	if (response != GTK_RESPONSE_OK) {
+		gtk_widget_hide (chooser);
+		gtk_main_quit ();
+		return;
+	}
+
+	file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
 
 	if (!g_file_test (file_name, G_FILE_TEST_EXISTS)) {
-		const gchar *pattern;
-
 		g_message ("!file exists in file_dialog_ok: %s", file_name);
-
-		if (fsel->selection_entry == NULL)
-			return;
-
-		pattern = 
-			gtk_entry_get_text (GTK_ENTRY (fsel->selection_entry));
-		gtk_file_selection_complete (fsel, pattern);
-
 	} else if (g_file_test (file_name, G_FILE_TEST_IS_DIR)) {
 		/* Change into directory if that's what the user selected */
-		gint name_len;
 		gchar *dir_name;
 
-		name_len = strlen (file_name);
-		if (name_len < 1 || file_name [name_len - 1] != '/') {
-			/* Needed for the file selector */
-			dir_name = g_strconcat (file_name, "/", NULL);
+		if (strlen (file_name) < 1) {
+			dir_name = g_strdup ("/");
 		} else {
 			dir_name = g_strdup (file_name);
 		}
 
-		gtk_file_selection_set_filename (fsel, dir_name);
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser),
+						     dir_name);
 		g_free (dir_name);
 	} else {
-		gtk_widget_hide (GTK_WIDGET (fsel));
+		gtk_widget_hide (chooser);
 		gtk_main_quit ();
 		*dialog_result = TRUE;
 	}
-}
 
-static void
-file_dialog_cancel (GtkWidget *widget, gpointer user_data)
-{
-	gtk_widget_hide (
-		gtk_widget_get_ancestor (widget, GTK_TYPE_FILE_SELECTION));
-	gtk_main_quit ();
+	g_free (file_name);
 }
 
 static guint
@@ -434,57 +436,58 @@ file_dialog_delete_event (GtkWidget *widget, GdkEventAny *event)
 static gboolean
 gw_ask_for_uri (GPdfWindow *gpdf_window, gchar ***uri)
 {
-	GtkFileSelection *fsel;
+	GtkFileChooser *chooser;
 	gboolean accepted = FALSE;
 
 	g_return_val_if_fail (GPDF_IS_NON_NULL_WINDOW (gpdf_window), FALSE);
 	g_return_val_if_fail (uri, FALSE);
 	g_return_val_if_fail (*uri == NULL, FALSE);
 
-	fsel = GTK_FILE_SELECTION (gtk_file_selection_new (_("Load file")));
-	gtk_file_selection_set_select_multiple (fsel, TRUE); 
-	gtk_window_set_modal (GTK_WINDOW (fsel), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW (fsel),
-				      GTK_WINDOW (gpdf_window));
+	chooser = GTK_FILE_CHOOSER (gtk_file_chooser_dialog_new (_("Load file"),
+								 GTK_WINDOW (gpdf_window),
+								 GTK_FILE_CHOOSER_ACTION_OPEN,
+								 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+								 GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+								 NULL));
+	gtk_file_chooser_set_select_multiple (chooser, TRUE); 
+	gtk_window_set_modal (GTK_WINDOW (chooser), TRUE);
 
 	/* Connect the signals for Ok and Cancel */
-	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
-			  G_CALLBACK (file_dialog_ok), &accepted);
-	g_signal_connect (G_OBJECT (fsel->cancel_button), "clicked",
-			  G_CALLBACK (file_dialog_cancel), NULL);
+	g_signal_connect (G_OBJECT (chooser), "response",
+			  G_CALLBACK (file_dialog_response), &accepted);
 
-	gtk_window_set_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
+	gtk_window_set_position (GTK_WINDOW (chooser), GTK_WIN_POS_MOUSE);
 
 	/* Make sure that we quit the main loop if the window is destroyed */
-	g_signal_connect (G_OBJECT (fsel), "delete_event",
+	g_signal_connect (G_OBJECT (chooser), "delete_event",
 			  G_CALLBACK (file_dialog_delete_event), NULL);
 
 	/* Run the dialog */
-	gtk_widget_show (GTK_WIDGET (fsel));
-	gtk_grab_add (GTK_WIDGET (fsel));
+	gtk_widget_show (GTK_WIDGET (chooser));
+	gtk_grab_add (GTK_WIDGET (chooser));
 	gtk_main ();
 
 	if (accepted) {
-		gchar **files;
+		GSList *files, *iter;
 		guint n; 
 
-		files = gtk_file_selection_get_selections (fsel);
+		files = gtk_file_chooser_get_filenames (chooser);
 
-		n = 0; 
-		while (files[n]) 
-			n++;
-		*uri = g_new (gchar*, n+1);
+		*uri = g_new (gchar*, g_slist_length (files) + 1);
 
-		n = 0; 
-		while (files[n]) {
+		n = 0;
+		for (iter = files; iter != NULL; iter = iter->next) {
 			(*uri)[n] =
-				gnome_vfs_get_uri_from_local_path (files[n]);
+				gnome_vfs_get_uri_from_local_path (iter->data);
+			g_free (iter->data);
 			n++;
 		}
 		(*uri)[n] = NULL; 
+
+		g_slist_free (files);
 	}
 
-	gtk_widget_destroy (GTK_WIDGET (fsel));
+	gtk_widget_destroy (GTK_WIDGET (chooser));
 
 	return accepted;
 }
